@@ -1,23 +1,24 @@
-# @(#)Ident: CPANDistributions.pm 2013-11-21 23:30 pjf ;
+# @(#)Ident: CPANDistributions.pm 2014-01-15 16:31 pjf ;
 
 package Module::Provision::TraitFor::CPANDistributions;
 
 use namespace::sweep;
-use version;  our $VERSION = qv( sprintf '0.29.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version;  our $VERSION = qv( sprintf '0.31.%d', q$Rev: 2 $ =~ /\d+/gmx );
 
 use Class::Usul::Constants;
 use Class::Usul::Crypt::Util qw( decrypt_from_config encrypt_for_config
                                  is_encrypted );
-use Class::Usul::Functions   qw( ensure_class_loaded throw );
+use Class::Usul::Functions   qw( ensure_class_loaded io throw );
 use Class::Usul::Types       qw( NonEmptySimpleStr );
 use English                  qw( -no_match_vars );
 use HTTP::Request::Common    qw( POST );
 use HTTP::Status;
 use Scalar::Util             qw( blessed );
+use Unexpected::Functions    qw( PathNotFound Unspecified );
 use Moo::Role;
 
 requires qw( add_leader config debug distname dist_version dumper
-             info io loc log next_argv output yorn );
+             info loc log next_argv output yorn );
 
 # Private attributes
 has '_debug_http_method' => is => 'ro', isa => NonEmptySimpleStr,
@@ -33,7 +34,7 @@ sub cpan_upload : method {
       -f $file or $file = $self->distname.'-v'.$self->dist_version.'.tar.gz';
    }
 
-   -f $file or throw $self->loc( 'File [_1] not found', $file );
+   -f $file or throw class => PathNotFound, args => [ $file ];
 
    ensure_class_loaded( 'CPAN::Uploader' );
 
@@ -71,7 +72,8 @@ sub delete_cpan_files : method {
 sub set_cpan_password : method {
    my $self = shift; my $args = $self->_read_rc_file;
 
-   $args->{password} = $self->next_argv or throw $self->loc( 'No password' );
+   $args->{password} = $self->next_argv
+      or throw class => Unspecified, args  => [ 'password' ];
    $self->_write_rc_file( $args );
    return OK;
 }
@@ -150,18 +152,19 @@ sub _log_http_debug {
 sub _read_rc_file {
    my $self = shift; my $dir = $self->config->my_home; my $attr = {};
 
-   for ($self->io( [ $dir, '.pause' ] )->chomp->getlines) {
+   for (io( [ $dir, '.pause' ] )->chomp->getlines) {
       ($_ and $_ !~ m{ \A \s* \# }mx) or next;
 
       my ($k, $v) = m{ \A \s* (\w+) (?: \s+ (.+))? \z }mx;
 
       exists $attr->{ $k }
-         and throw $self->loc( 'Multiple enties for [_1]', $k );
-      $attr->{ $k } = $v || NUL;
+         and throw error => 'Multiple entries for [_1]', args => [ $k ];
+      $attr->{ $k } = $v // NUL;
    }
 
    my $pword; exists $attr->{password}
-      and $pword = $attr->{password} and is_encrypted( $pword )
+      and $pword = $attr->{password}
+      and is_encrypted( $pword )
       and $attr->{password} = decrypt_from_config( $self->config, $pword );
 
    return $attr;
@@ -170,20 +173,21 @@ sub _read_rc_file {
 sub _throw_on_error {
    my ($self, $uri, $target, $response) = @_;
 
-   defined $response or throw $self->loc
-      ( 'Request completely failed - we got undef back: [_1]', $OS_ERROR );
+   defined $response
+      or throw error => 'Request completely failed - we got undef back: [_1]',
+               args  => [ $OS_ERROR ];
 
    if ($response->is_error) {
       my $class = blessed $self || $self;
 
-      $response->code == RC_NOT_FOUND and throw $self->loc
-         (  "PAUSE's CGI for handling messages seems to have moved!\n".
-            "(HTTP response code of 404 from the [_1] web server)\n".
-            "It used to be: [_2]\nPlease inform the maintainer of [_3]\n",
-            $target, $uri, $class );
+      $response->code == RC_NOT_FOUND and throw error =>
+         "PAUSE's CGI for handling messages seems to have moved!\n".
+         "(HTTP response code of 404 from the [_1] web server)\n".
+         "It used to be: [_2]\nPlease inform the maintainer of [_3]\n",
+         args => [ $target, $uri, $class ];
 
-      throw $self->loc( "Request failed error code [_1]\n  Message: [_2]\n",
-                        $response->code, $response->message );
+      throw error => "Request failed error code [_1]\n  Message: [_2]\n",
+            args  => [ $response->code, $response->message ];
    }
 
    $self->_log_http_debug( 'RESPONSE', $response, 'Looks OK!' );
@@ -233,7 +237,7 @@ Module::Provision::TraitFor::CPANDistributions - Uploads/Deletes distributions t
 
 =head1 Version
 
-This documents version v0.29.$Rev: 1 $ of
+This documents version v0.31.$Rev: 2 $ of
 L<Module::Provision::TraitFor::CPANDistributions>
 
 =head1 Description
